
# Slot: has participant


holds between a process and a continuant, where the continuant is somehow involved in the process

URI: [biolink:has_participant](https://w3id.org/biolink/vocab/has_participant)


## Domain and Range

[Occurrent](Occurrent.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [enabled by](enabled_by.md)
 *  [has input](has_input.md)
 *  [has output](has_output.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0000057 |
|  | | RO:has_participant |
| **Close Mappings:** | | WIKIDATA_PROPERTY:P2283 |
| **Narrow Mappings:** | | BFO:0000167 |
|  | | LOINC:has_subject |
|  | | NCIT:pathway_has_gene_element |
|  | | NCIT:process_involves_gene |
|  | | OBO:nbo#has_participant |
|  | | PathWhiz:has_bound |
|  | | PathWhiz:has_compound |
|  | | PathWhiz:has_element_collection |
|  | | PathWhiz:has_enzyme |
|  | | NCIT:process_includes_biological_process |
|  | | OBI:0000293 |
|  | | PathWhiz:has_nucleic_acid |
|  | | PathWhiz:has_protein |
|  | | PathWhiz:has_reaction |
|  | | RO:0004007 |
|  | | RO:0004020 |
|  | | RO:0004021 |
|  | | SNOMED:has_indirect_device |
|  | | SNOMED:has_procedure_device |
|  | | SNOMED:has_recipient_category |

